anesthetic.gui package
======================

Submodules
----------

anesthetic.gui.plot module
--------------------------

.. automodule:: anesthetic.gui.plot
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.gui.widgets module
-----------------------------

.. automodule:: anesthetic.gui.widgets
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: anesthetic.gui
    :members:
    :undoc-members:
    :show-inheritance:
